@@ -16,6 +16,7 @@
 # - Cedric Serfon <cedric.serfon@cern.ch>, 2017
 # - Vincent Garonne <vgaronne@gmail.com>, 2018
 # - Martin Barisits <martin.barisits@cern.ch>, 2018
+# - Andrew Lister <andrew.lister@stfc.ac.uk>, 2019
 
 from __future__ import print_function
 
@@ -33,9 +34,6 @@ class LifetimeClient(BaseClient):
 
     LIFETIME_BASEURL = 'lifetime_exceptions'
 
-    def __init__(self, rucio_host=None, auth_host=None, account=None, ca_cert=None, auth_type=None, creds=None, timeout=600, user_agent='rucio-clients'):
-        super(LifetimeClient, self).__init__(rucio_host, auth_host, account, ca_cert, auth_type, creds, timeout, user_agent)
-
     def list_exceptions(self, exception_id=None, states=None):
         """
         List exceptions to Lifetime Model.
@@ -76,7 +74,7 @@ class LifetimeClient(BaseClient):
         url = build_url(choice(self.list_hosts), path=path)
         data = {'dids': dids, 'account': account, 'pattern': pattern, 'comments': comments, 'expires_at': expires_at}
         print(render_json(**data))
-        result = self._send_request(url, type='POST', data=render_json(**data))
+        result = self._send_request(url, type_='POST', data=render_json(**data))
         print(result.text)
         if result.status_code == codes.created:
             return loads(result.text)
