@@ -45,9 +45,6 @@ class ReplicaClient(BaseClient):
 
     REPLICAS_BASEURL = 'replicas'
 
-    def __init__(self, rucio_host=None, auth_host=None, account=None, ca_cert=None, auth_type=None, creds=None, timeout=600, user_agent='rucio-clients', vo=None):
-        super(ReplicaClient, self).__init__(rucio_host, auth_host, account, ca_cert, auth_type, creds, timeout, user_agent, vo=vo)
-
     def declare_bad_file_replicas(self, pfns, reason):
         """
         Declare a list of bad replicas.
@@ -58,7 +55,7 @@ class ReplicaClient(BaseClient):
         data = {'reason': reason, 'pfns': pfns}
         url = build_url(self.host, path='/'.join([self.REPLICAS_BASEURL, 'bad']))
         headers = {}
-        r = self._send_request(url, headers=headers, type='POST', data=dumps(data))
+        r = self._send_request(url, headers=headers, type_='POST', data=dumps(data))
         if r.status_code == codes.created:
             return loads(r.text)
         exc_cls, exc_msg = self._get_exception(headers=r.headers, status_code=r.status_code, data=r.content)
@@ -75,7 +72,7 @@ class ReplicaClient(BaseClient):
         data = {'reason': reason, 'rse': rse, 'dids': dids}
         url = build_url(self.host, path='/'.join([self.REPLICAS_BASEURL, 'bad/dids']))
         headers = {}
-        r = self._send_request(url, headers=headers, type='POST', data=dumps(data))
+        r = self._send_request(url, headers=headers, type_='POST', data=dumps(data))
         if r.status_code == codes.created:
             return loads(r.text)
         exc_cls, exc_msg = self._get_exception(headers=r.headers, status_code=r.status_code, data=r.content)
@@ -91,7 +88,7 @@ class ReplicaClient(BaseClient):
         data = {'reason': reason, 'pfns': pfns}
         url = build_url(self.host, path='/'.join([self.REPLICAS_BASEURL, 'suspicious']))
         headers = {}
-        r = self._send_request(url, headers=headers, type='POST', data=dumps(data))
+        r = self._send_request(url, headers=headers, type_='POST', data=dumps(data))
         if r.status_code == codes.created:
             return loads(r.text)
         exc_cls, exc_msg = self._get_exception(headers=r.headers, status_code=r.status_code, data=r.content)
@@ -108,7 +105,7 @@ class ReplicaClient(BaseClient):
         data = {'rse': rse, 'pfns': pfns}
         url = build_url(self.host, path='/'.join([self.REPLICAS_BASEURL, 'dids']))
         headers = {}
-        r = self._send_request(url, headers=headers, type='POST', data=dumps(data))
+        r = self._send_request(url, headers=headers, type_='POST', data=dumps(data))
         if r.status_code == codes.ok:
             return self._load_json_data(r)
         exc_cls, exc_msg = self._get_exception(headers=r.headers, status_code=r.status_code, data=r.content)
@@ -187,7 +184,7 @@ class ReplicaClient(BaseClient):
             headers['Accept'] = 'application/metalink4+xml'
 
         # pass json dict in querystring
-        r = self._send_request(url, headers=headers, type='POST', data=dumps(data), stream=True)
+        r = self._send_request(url, headers=headers, type_='POST', data=dumps(data), stream=True)
         if r.status_code == codes.ok:
             if not metalink:
                 return self._load_json_data(r)
@@ -217,20 +214,20 @@ class ReplicaClient(BaseClient):
 
         url = build_url(choice(self.list_hosts),
                         path='/'.join([self.REPLICAS_BASEURL, 'suspicious']))
-        r = self._send_request(url, type='GET', params=params)
+        r = self._send_request(url, type_='GET', params=params)
         if r.status_code == codes.ok:
             return self._load_json_data(r)
         exc_cls, exc_msg = self._get_exception(headers=r.headers, status_code=r.status_code, data=r.content)
         raise exc_cls(exc_msg)
 
-    def add_replica(self, rse, scope, name, bytes, adler32, pfn=None, md5=None, meta={}):
+    def add_replica(self, rse, scope, name, bytes_, adler32, pfn=None, md5=None, meta={}):
         """
         Add file replicas to a RSE.
 
         :param rse: the RSE name.
         :param scope: The scope of the file.
         :param name: The name of the file.
-        :param bytes: The size in bytes.
+        :param bytes_: The size in bytes.
         :param adler32: adler32 checksum.
         :param pfn: PFN of the file for non deterministic RSE.
         :param md5: md5 checksum.
@@ -239,12 +236,12 @@ class ReplicaClient(BaseClient):
         :return: True if files were created successfully.
 
         """
-        dict = {'scope': scope, 'name': name, 'bytes': bytes, 'meta': meta, 'adler32': adler32}
+        dict_ = {'scope': scope, 'name': name, 'bytes': bytes_, 'meta': meta, 'adler32': adler32}
         if md5:
-            dict['md5'] = md5
+            dict_['md5'] = md5
         if pfn:
-            dict['pfn'] = pfn
-        return self.add_replicas(rse=rse, files=[dict])
+            dict_['pfn'] = pfn
+        return self.add_replicas(rse=rse, files=[dict_])
 
     def add_replicas(self, rse, files, ignore_availability=True):
         """
@@ -260,7 +257,7 @@ class ReplicaClient(BaseClient):
         """
         url = build_url(choice(self.list_hosts), path=self.REPLICAS_BASEURL)
         data = {'rse': rse, 'files': files, 'ignore_availability': ignore_availability}
-        r = self._send_request(url, type='POST', data=render_json(**data))
+        r = self._send_request(url, type_='POST', data=render_json(**data))
         if r.status_code == codes.created:
             return True
         exc_cls, exc_msg = self._get_exception(headers=r.headers, status_code=r.status_code, data=r.content)
@@ -280,7 +277,7 @@ class ReplicaClient(BaseClient):
         """
         url = build_url(choice(self.list_hosts), path=self.REPLICAS_BASEURL)
         data = {'rse': rse, 'files': files, 'ignore_availability': ignore_availability}
-        r = self._send_request(url, type='DEL', data=render_json(**data))
+        r = self._send_request(url, type_='DEL', data=render_json(**data))
         if r.status_code == codes.ok:
             return True
         exc_cls, exc_msg = self._get_exception(headers=r.headers, status_code=r.status_code, data=r.content)
@@ -306,7 +303,7 @@ class ReplicaClient(BaseClient):
         """
         url = build_url(choice(self.list_hosts), path=self.REPLICAS_BASEURL)
         data = {'rse': rse, 'files': files}
-        r = self._send_request(url, type='PUT', data=render_json(**data))
+        r = self._send_request(url, type_='PUT', data=render_json(**data))
         if r.status_code == codes.ok:
             return True
         exc_cls, exc_msg = self._get_exception(headers=r.headers, status_code=r.status_code, data=r.content)
@@ -330,7 +327,7 @@ class ReplicaClient(BaseClient):
         url = build_url(self.host,
                         path='/'.join([self.REPLICAS_BASEURL, quote_plus(scope), quote_plus(name), 'datasets']),
                         params=payload)
-        r = self._send_request(url, type='GET')
+        r = self._send_request(url, type_='GET')
         if r.status_code == codes.ok:
             return self._load_json_data(r)
         exc_cls, exc_msg = self._get_exception(headers=r.headers, status_code=r.status_code, data=r.content)
@@ -346,7 +343,7 @@ class ReplicaClient(BaseClient):
         """
         payload = {'dids': list(dids)}
         url = build_url(self.host, path='/'.join([self.REPLICAS_BASEURL, 'datasets_bulk']))
-        r = self._send_request(url, type='POST', data=dumps(payload))
+        r = self._send_request(url, type_='POST', data=dumps(payload))
         if r.status_code == codes.ok:
             return self._load_json_data(r)
         exc_cls, exc_msg = self._get_exception(headers=r.headers, status_code=r.status_code, data=r.content)
@@ -372,7 +369,7 @@ class ReplicaClient(BaseClient):
         url = build_url(self.host,
                         path='/'.join([self.REPLICAS_BASEURL, quote_plus(scope), quote_plus(name), 'datasets_vp']),
                         params=payload)
-        r = self._send_request(url, type='GET')
+        r = self._send_request(url, type_='GET')
         if r.status_code == codes.ok:
             return self._load_json_data(r)
         exc_cls, exc_msg = self._get_exception(headers=r.headers, status_code=r.status_code, data=r.content)
@@ -390,7 +387,7 @@ class ReplicaClient(BaseClient):
 
         """
         url = build_url(self.host, path='/'.join([self.REPLICAS_BASEURL, 'rse', rse]))
-        r = self._send_request(url, type='GET')
+        r = self._send_request(url, type_='GET')
         if r.status_code == codes.ok:
             return self._load_json_data(r)
 
@@ -412,7 +409,7 @@ class ReplicaClient(BaseClient):
         data = {'reason': reason, 'pfns': pfns, 'state': state, 'expires_at': expires_at}
         url = build_url(self.host, path='/'.join([self.REPLICAS_BASEURL, 'bad/pfns']))
         headers = {}
-        r = self._send_request(url, headers=headers, type='POST', data=dumps(data))
+        r = self._send_request(url, headers=headers, type_='POST', data=dumps(data))
         if r.status_code == codes.created:
             return True
         exc_cls, exc_msg = self._get_exception(headers=r.headers, status_code=r.status_code, data=r.content)
@@ -426,7 +423,7 @@ class ReplicaClient(BaseClient):
         """
         url = build_url(self.host, path='/'.join([self.REPLICAS_BASEURL, 'tombstone']))
         data = {'replicas': replicas}
-        r = self._send_request(url, type='POST', data=render_json(**data))
+        r = self._send_request(url, type_='POST', data=render_json(**data))
         if r.status_code == codes.created:
             return True
         exc_cls, exc_msg = self._get_exception(headers=r.headers, status_code=r.status_code, data=r.content)
