@@ -36,7 +36,6 @@ import xml.etree.ElementTree as ET
 from xml.parsers import expat
 
 import requests
-from progressbar import ProgressBar
 from requests.adapters import HTTPAdapter
 from urllib3.poolmanager import PoolManager
 
@@ -275,23 +274,14 @@ class Default(protocol.RSEProtocol):
                 length = None
                 if 'content-length' in result.headers:
                     length = int(result.headers['content-length'])
-                    totnchunk = int(length / chunksize) + 1
                 with open(dest, 'wb') as file_out:
                     nchunk = 0
-                    try:
+                    if not length:
+                        print('Malformed HTTP response (missing content-length header).')
+                    for chunk in result.iter_content(chunksize):
+                        file_out.write(chunk)
                         if length:
-                            pbar = ProgressBar(maxval=totnchunk).start()
-                        else:
-                            print('Malformed HTTP response (missing content-length header). Cannot show progress bar.')
-                        for chunk in result.iter_content(chunksize):
-                            file_out.write(chunk)
-                            if length:
-                                nchunk += 1
-                                pbar.update(nchunk)
-                    finally:
-                        if length:
-                            pbar.finish()
-
+                            nchunk += 1
             elif result.status_code in [404, ]:
                 raise exception.SourceNotFound()
             elif result.status_code in [401, 403]:
@@ -498,7 +488,7 @@ class Default(protocol.RSEProtocol):
         """
         raise NotImplementedError
         headers = {'Depth': '1'}
-        dict = {}
+        dict_ = {}
         try:
             result = self.session.request('PROPFIND', path, verify=False, headers=headers, timeout=self.timeout, cert=self.cert)
             if result.status_code in [404, ]:
@@ -511,9 +501,9 @@ class Default(protocol.RSEProtocol):
             parser.feed(result.text)
             for file_name in parser.sizes:
                 if '%s%s' % (self.server, file_name) == path:
-                    dict['size'] = parser.sizes[file_name]
+                    dict_['size'] = parser.sizes[file_name]
             parser.close()
-            return dict
+            return dict_
         except requests.exceptions.ConnectionError as error:
             raise exception.ServiceUnavailable(error)
         except requests.exceptions.ReadTimeout as error:
